@@ -93,16 +93,6 @@ sub new {
   return $new;
 }
 
-sub get_simple {
-  my ($self, $get) = @_;
-  return $self->{$get};
-}
-
-sub set_simple {
-  my ($self, $set, $val) = @_;
-  return $self->{$set} = $val;
-}
-
 =head1 NAME 
 
 DBIx::Class::Storage::DBI - DBI storage handler
